Package: HaDeX
Title: Analysis and Visualisation of Hydrogen/Deuterium Exchange Mass
        Spectrometry Data
Version: 1.2.3
Authors@R: c(person("Weronika", "Puchala", 
           email = "puchala.weronika@gmail.com", 
           comment = c(ORCID = "0000-0003-2163-1429"),
           role = c("cre", "aut")),
           person("Michal", "Burdukiewicz", 
           email = "michalburdukiewicz@gmail.com", 
           comment = c(ORCID = "0000-0001-8926-582X"),
           role = c("aut")),
           person("Dominik", "Rafacz", 
           email = "d.rafacz@student.mini.pw.edu.pl",
           comment = c(ORCID = "0000-0003-0925-1909"),
           role = c("ctb")))
Description: Functions for processing, analysis and visualization of Hydrogen Deuterium eXchange monitored by 
             Mass Spectrometry experiments (HDX-MS) (<doi:10.1093/bioinformatics/btaa587>). 'HaDeX' introduces a new 
             standardized and reproducible workflow for the analysis of the HDX-MS data, including novel 
             uncertainty intervals. Additionally, it covers data exploration, quality control and generation of 
             publication-quality figures. All functionalities are also available in the in-built 'Shiny' app.
Depends: R (>= 3.0)
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: data.table, dplyr, ggplot2, latex2exp, reshape2, readr,
        readxl, shiny, tidyr
Suggests: spelling, covr, digest, DT, gridExtra, gsubfn, knitr, pander,
        renv, rmarkdown, shinycssloaders, shinyhelper, shinyjs,
        stringr, testthat, vdiffr
VignetteBuilder: knitr
Language: en-US
NeedsCompilation: no
Packaged: 2025-07-04 09:15:50 UTC; User
Author: Weronika Puchala [cre, aut] (ORCID:
    <https://orcid.org/0000-0003-2163-1429>),
  Michal Burdukiewicz [aut] (ORCID:
    <https://orcid.org/0000-0001-8926-582X>),
  Dominik Rafacz [ctb] (ORCID: <https://orcid.org/0000-0003-0925-1909>)
Maintainer: Weronika Puchala <puchala.weronika@gmail.com>
Repository: CRAN
Date/Publication: 2025-07-04 12:20:02 UTC
Built: R 4.6.0; ; 2026-04-26 18:52:56 UTC; unix
