# Generated by roxygen2: do not edit by hand

export(HaDeX_gui)
export(add_stat_dependency)
export(calculate_confidence_limit_values)
export(calculate_kinetics)
export(calculate_state_deuteration)
export(comparison_plot)
export(plot_coverage)
export(plot_kinetics)
export(plot_position_frequency)
export(prepare_dataset)
export(quality_control)
export(read_hdx)
export(reconstruct_sequence)
export(woods_plot)
importFrom(data.table,fread)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,coalesce)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,summarize)
importFrom(dplyr,sym)
importFrom(dplyr,ungroup)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_errorbar)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_colour_identity)
importFrom(ggplot2,scale_linetype_manual)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(latex2exp,TeX)
importFrom(readr,col_character)
importFrom(readr,cols)
importFrom(readr,parse_character)
importFrom(readr,parse_double)
importFrom(readr,parse_integer)
importFrom(readr,parse_logical)
importFrom(readr,read_csv)
importFrom(readr,read_tsv)
importFrom(readxl,read_excel)
importFrom(reshape2,melt)
importFrom(shiny,runApp)
importFrom(stats,qt)
importFrom(stats,sd)
importFrom(stats,weighted.mean)
importFrom(tidyr,spread)
importFrom(tidyr,unite)
importFrom(tools,file_ext)
