## Choose protein

HaDeX accepts files with more than one protein, but all the calculations are done for the chosen protein. The name of the chosen protein is preserved in all of the tabs and all of the plot titles. 