## Choose confidence limit 

To check if the results on the Woods plot are statistically significant, the confidence limit is calculated and shown on the plot.
The calculation method is developed by Houde et al. and can be seen [here](https://www.sciencedirect.com/science/article/abs/pii/S0022354915320955?via%3Dihub).