## Woods plot

Woods plots show the difference between the deuteration of all peptides in two different states in a specific time point as described by the following equation:

$$diff = D_{1} - D_{2}$$

To get more information, check the [documentation](https://hadexversum.github.io/HaDeX/articles/overview.html#woods-plot).