## Choose peptides from the table

Clik on desired peptides to see them on the kinetics plot on the right. 
If you want to narrow search of the available peptides, use the tools in the down of the table - 
you can search based on motif or start/end position range.

If you want to deselect all of the chosen peptides, click on `Reset chosen peptides` button.