## Choose control value

Choose one of the measurements (a state measured in a specific timepoint) supplied in the file as the control measurement. You can only choose state and exposure for chosen protein as a control.
