## Second state

On the Woods plot, the difference between state 1 and state 2 is shown.
Here choose the second state - make sure it is different than the first state. Otherwise, no result is produced.