## Uptake curve

This plot shows the levels of exchange for each measured time point for each chosen peptide from the table on the left - the informativity is the same as `uptake curve` plots available in DynamX 3.0. 

Sometimes it is also referred to as `Kinetics`. 

Please keep in mind that the calculations are made for time points (shown on the plot as black dots), and the lines between them are just an approximation.

To get more information, check the [documentation](https://hadexversum.github.io/HaDeX/articles/overview.html#kinetic-plots).