## Calculation types

In HaDeX, we support two methods of calculating the results.

### Theoretical

This method compares measure deuterium uptake with theoretical values. The correction of the D2O concentration is made in the Settings panel.

As a consequence of this method, the information on the back-exchange in the experiment is lost.

To get more insight, check the [documentation](https://hadexversum.github.io/HaDeX/articles/overview.html#theoretical-deuteration-level).

### Experimental (default)

The measured deuterium uptake in chosen time is compared with measured undeuterated value and measured control sample for each state. 

For more information, check the [documentation](https://hadexversum.github.io/HaDeX/articles/overview.html#experimental-deuteration-level).