## Choose second confidence limit 

If you wish to see how the results change depending on the different confidence limits, choose the second confidence limit.

If the second confidence limit is the same as the first one, only one is shown on the plot.