## About  

The HaDeX web server relies on functions from the [HaDeX](https://github.com/michbur/HaDeX) **R** package. For more information check our [documentation](https://hadexversum.github.io/HaDeX/). 

### Authors  

* [Weronika Puchała](https://github.com/werpuc)
* [Michał Burdukiewicz](https://www.researchgate.net/profile/Michal_Burdukiewicz)

### Citation

Puchala W, Burdukiewicz M, Kistowski M, Dabrowska KA, Badaczewska-Dawid AE, Cysewski D and Dadlez M (2020). HaDeX: Analysis and Visualisation of Hydrogen/Deuterium Exchange Mass Spectrometry Data. Bioinformatics, 10.1093/bioinformatics/btaa587.

### Funding  

This work is supported by Foundation of Polish Science (TEAM TECH CORE FACILITY/2016-2/2 *Mass Spectrometry of Biopharmaceuticals - improved methodologies for qualitative, quantitative and structural characterization of drugs, proteinaceous drug targets and diagnostic molecules)* and Narodowe Centrum Nauki (Preludium Bis 1 2019/35/O/NZ2/03745 Wysokorozdzielcza analiza danych z eksperymentów wymiany proton-deuter monitorowanych spektrometrią mas).

### Links

- [Mass Spectrometry Laboratory, IBB PAS](https://mslab-ibb.pl/en/)
- [MI2 DataLab](https://mi2-warsaw.github.io/)
