## Choose `out` time for calculations

This value is treated as an approximation of a fully deuterated sample for the experimental calculation type. If the control in the Settings panel is chosen, this control is a reference time point for all states. Otherwise, measurements are compared with the measurement in the same state in the chosen time point. 

Be careful with using this option if you do not have measurements for all states in all time points.
