## Comparison plot

The comparison shows the deuterium uptake for every chosen state in one plot. The parameters are to be adjusted on the left panel.

To get more information about constructing these plots, check the [documentation](https://hadexversum.github.io/HaDeX/articles/overview.html#comparison-of-states).