## Adjust colors

There is a possibility of changing the colors associated with states of the peptides on the comparison plot.
Just change the HTML color code of a state with the desired one.

If you need help with the color codes, check this [page](https://coolors.co/app).