## Deuterium concentration

For theoretical calculations, the deuterium concentration in the buffer is included in deuterium uptake calculations. You can adjust the percentage value of deuterium concentration here. 