## Choose calculation results type values 

### Relative (default) 

The results are shown as the percentage of maximum deuteration - measured sample in case of experimental calculations or with theoretical values.

### Absolute 

The results are shown in Daltons.
