## Quality control

The plot shows the change in the uncertainty of deuteration levels as a function of incubation time. The uncertainty is averaged over all peptides available at a given time point in a selected state. Therefore, the user can detect if the uncertainty of deuteration measurements decreases over time (as expected in the majority of experiments).

Moreover, the user can use this chart to identify a time point, after which the decrease of the deuteration uncertainty becomes too marginal to prolong the measurements. 

Please keep in mind that the calculations are made for time points (shown on the plot as black dots), and the lines between them are just an approximation.

To get more information, check the [documentation](https://hadexversum.github.io/HaDeX/articles/overview.html#quality-control).
